==> ra-sdk-0.0.1-20191227.014025-3-sources.jar: com/xdja/ra/bean/UserCertInfo.java <==
package com.xdja.ra.bean;

import java.sql.Timestamp;

/**
 * @author: ggp
 * @Date: 2019/10/23 08:54
 * @Description:
 */
public class UserCertInfo {
    /**
     *必须	证书主体
     */
    private String certDn;
    /**
     *必须	证书状态 0:待确认 1:正常 2:已过期 3:已撤销
     */
    private Integer certStatus;
    /**
     *必须	证书有效期
     */
    private Integer certValidity;
    /**
     *必须	证书生效时间
     */
    private Timestamp effectiveTime;
    /**
     * 必须	加密证书sn
     */
    private String encSn;
    /**
     * 必须	证书失效时间
     */
    private Timestamp failureTime;
    /**
     * 必须	剩余证书有效期
     */
    private Integer leftValidity;
    /**
     * 必须	密钥长度
     */
    private Integer privateKeyLength;
    /**
     * 必须	证书签名算法
     */
    private String signAlg;
    /**
     * 必须	签名证书sn
     */
    private String signSn;

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertStatus() {
        return certStatus;
    }

    public void setCertStatus(Integer certStatus) {
        this.certStatus = certStatus;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public Timestamp getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(Timestamp effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public Timestamp getFailureTime() {
        return failureTime;
    }

    public void setFailureTime(Timestamp failureTime) {
        this.failureTime = failureTime;
    }

    public Integer getLeftValidity() {
        return leftValidity;
    }

    public void setLeftValidity(Integer leftValidity) {
        this.leftValidity = leftValidity;
    }

    public Integer getPrivateKeyLength() {
        return privateKeyLength;
    }

    public void setPrivateKeyLength(Integer privateKeyLength) {
        this.privateKeyLength = privateKeyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    @Override
    public String toString() {
        return "UserCertInfo{" +
                "certDn='" + certDn + '\'' +
                ", certStatus=" + certStatus +
                ", certValidity=" + certValidity +
                ", effectiveTime=" + effectiveTime +
                ", encSn='" + encSn + '\'' +
                ", failureTime=" + failureTime +
                ", leftValidity=" + leftValidity +
                ", privateKeyLength=" + privateKeyLength +
                ", signAlg='" + signAlg + '\'' +
                ", signSn='" + signSn + '\'' +
                '}';
    }
}

==> ra-sdk-2.0.0-sources.jar: com/xdja/ra/bean/UserCertInfo.java <==
package com.xdja.ra.bean;

/**
 * @author: ggp
 * @Date: 2019/10/23 08:54
 * @Description:
 */
public class UserCertInfo {
    /**
     *必须	证书主体
     */
    private String certDn;
    /**
     *必须	证书状态 0:待确认 1:正常 2:已过期 3:已撤销
     */
    private Integer certStatus;
    /**
     *必须	证书有效期
     */
    private Integer certValidity;
    /**
     *必须	证书生效时间
     */
    private String effectiveTime;
    /**
     * 必须	加密证书sn
     */
    private String encSn;
    /**
     * 必须	证书失效时间
     */
    private String failureTime;
    /**
     * 必须	剩余证书有效期
     */
    private Integer leftValidity;
    /**
     * 必须	密钥长度
     */
    private Integer privateKeyLength;
    /**
     * 必须	证书签名算法
     */
    private String signAlg;
    /**
     * 必须	签名证书sn
     */
    private String signSn;

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public Integer getCertStatus() {
        return certStatus;
    }

    public void setCertStatus(Integer certStatus) {
        this.certStatus = certStatus;
    }

    public Integer getCertValidity() {
        return certValidity;
    }

    public void setCertValidity(Integer certValidity) {
        this.certValidity = certValidity;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public Integer getLeftValidity() {
        return leftValidity;
    }

    public void setLeftValidity(Integer leftValidity) {
        this.leftValidity = leftValidity;
    }

    public Integer getPrivateKeyLength() {
        return privateKeyLength;
    }

    public void setPrivateKeyLength(Integer privateKeyLength) {
        this.privateKeyLength = privateKeyLength;
    }

    public String getSignAlg() {
        return signAlg;
    }

    public void setSignAlg(String signAlg) {
        this.signAlg = signAlg;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public String getFailureTime() {
        return failureTime;
    }

    public void setFailureTime(String failureTime) {
        this.failureTime = failureTime;
    }

    @Override
    public String toString() {
        return "UserCertInfo{" +
                "certDn='" + certDn + '\'' +
                ", certStatus=" + certStatus +
                ", certValidity=" + certValidity +
                ", effectiveTime=" + effectiveTime +
                ", encSn='" + encSn + '\'' +
                ", failureTime=" + failureTime +
                ", leftValidity=" + leftValidity +
                ", privateKeyLength=" + privateKeyLength +
                ", signAlg='" + signAlg + '\'' +
                ", signSn='" + signSn + '\'' +
                '}';
    }
}
